@@ -344,7 +344,8 @@ def fit_StokesI_model(freqArr,IArr,dIArr,polyOrd,fit_function="log"):
                "p": None,
                "polyOrd":0,
                "AIC":0,
-               "reference_frequency_Hz":1}
+               "reference_frequency_Hz":1,
+               "perror": None}
 
     goodchan=np.logical_and(np.isfinite(IArr),np.isfinite(dIArr)) #Ignore NaN channels!
     #The fitting code is susceptible to numeric overflows because the frequencies are large.
@@ -385,6 +386,7 @@ def fit_StokesI_model(freqArr,IArr,dIArr,polyOrd,fit_function="log"):
     fitDict["chiSq"] = mp.fnorm
     fitDict["chiSqRed"] = mp.fnorm/fitDict["dof"]
     fitDict["nIter"] = mp.niter
+    fitDict["perror"] = mp.perror
 
 
     return fitDict
@@ -411,7 +413,12 @@ def renormalize_StokesI_model(fitDict,new_reference_frequency):
     and fixes the fit parameters such that the the model is the same. This is
     important because the initial Stokes I fitted model uses an arbitrary
     reference frequency, and it may be desirable for users to know the exact
-    reference frequency of the model."""
+    reference frequency of the model.
+    
+    This function is depreciated because it can't propagate the errors in 
+    the fit parameters."""
+    print("The renormalize_StokesI_model function is depreciated because it can't propagate errors.\n"
+          "If this message appears, it's been invoked (perhaps by legacy code?)")
     #Renormalization ratio:
     x=new_reference_frequency/fitDict['reference_frequency_Hz']
     (a,b,c,d,f,g)=fitDict['p']
@@ -453,7 +460,13 @@ def create_frac_spectra(freqArr, IArr, QArr, UArr, dIArr, dQArr, dUArr,
     elif modStokesI is None:
         # Fit a <=5th order polynomial model to the Stokes I spectrum
         try:
-            fitDict=fit_StokesI_model(freqArr,IArr,dIArr,polyOrd,fit_function)
+            #The input values are forced to 64-bit in order to maximize the
+            #stability and quality of the fits. It was found that the fitter
+            #is more susceptible to numerical issues in 32-bit.
+            fitDict=fit_StokesI_model(freqArr.astype('float64'),
+                                      IArr.astype('float64'),
+                                      dIArr.astype('float64'),
+                                      polyOrd,fit_function)
             IModArr = calculate_StokesI_model(fitDict,freqArr)
             
             if np.min(IModArr) < 0:   #Flag sources with negative models.
